<?php








function get_video_thumbnail( $post_id = null ) {

	// Get the post ID if none is provided
	if ( $post_id == null OR $post_id == '' ) $post_id = get_the_ID();

	// Check to see if thumbnail has already been found
	if( ( $thumbnail_meta = get_post_meta( $post_id, '_video_thumbnail', true ) ) != '' ) {
		return $thumbnail_meta;
	}
	// If the thumbnail isn't stored in custom meta, fetch a thumbnail
	else {

		// Get the post or custom field to search
		$video_key = 'multifolio_mediacontent';
 $markup = get_post_meta($post_id, $video_key, true);
 $new_thumbnail = null;

		// Simple Video Embedder Compatibility
		if ( function_exists( 'p75HasVideo' ) ) {
			if ( p75HasVideo( $post_id ) ) {
				$markup = p75GetVideo( $post_id );
			}
		}

		// Checks for the old standard YouTube embed
		preg_match( '#<object[^>]+>.+?https?://www\.youtube(?:\-nocookie)?\.com/[ve]/([A-Za-z0-9\-_]+).+?</object>#s', $markup, $matches );

		// More comprehensive search for YouTube embed, redundant but necessary until more testing is completed
		if ( !isset( $matches[1] ) ) {
			preg_match( '#https?://www\.youtube(?:\-nocookie)?\.com/[ve]/([A-Za-z0-9\-_]+)#', $markup, $matches );
		}

		// Checks for YouTube iframe, the new standard since at least 2011
		if ( !isset( $matches[1] ) ) {
			preg_match( '#https?://www\.youtube(?:\-nocookie)?\.com/embed/([A-Za-z0-9\-_]+)#', $markup, $matches );
		}

		// Checks for any YouTube URL. After http(s) support a or v for Youtube Lyte and v or vh for Smart Youtube plugin
		if ( !isset( $matches[1] ) ) {
			preg_match( '#(?:https?(?:a|vh?)?://)?(?:www\.)?youtube(?:\-nocookie)?\.com/watch\?.*v=([A-Za-z0-9\-_]+)#', $markup, $matches );
		}

		// Checks for any shortened youtu.be URL. After http(s) a or v for Youtube Lyte and v or vh for Smart Youtube plugin
		if ( !isset( $matches[1] ) ) {
			preg_match( '#(?:https?(?:a|vh?)?://)?youtu\.be/([A-Za-z0-9\-_]+)#', $markup, $matches );
		}

		// Checks for YouTube Lyte
		if ( !isset( $matches[1] ) && function_exists( 'lyte_parse' ) ) {
			preg_match( '#<div class="lyte" id="([A-Za-z0-9\-_]+)"#', $markup, $matches );
		}

		// If we've found a YouTube video ID, create the thumbnail URL
		if ( isset( $matches[1] ) ) {
			$youtube_thumbnail = 'http://img.youtube.com/vi/' . $matches[1] . '/0.jpg';

			// Check to make sure it's an actual thumbnail
			if ( ! function_exists( 'curl_init' ) ) {
				$new_thumbnail = $youtube_thumbnail;
			} else {
				$ch = curl_init( $youtube_thumbnail );
				curl_setopt( $ch, CURLOPT_NOBODY, true );
				curl_exec( $ch );
				$retcode = curl_getinfo( $ch, CURLINFO_HTTP_CODE );
				// $retcode > 400 -> not found, $retcode = 200, found.
				curl_close( $ch );
				if ( $retcode == 200 ) {
					$new_thumbnail = $youtube_thumbnail;
				}
			}
		}

		// Vimeo
		if ( $new_thumbnail == null ) {

			// Standard embed code
			preg_match( '#<object[^>]+>.+?http://vimeo\.com/moogaloop.swf\?clip_id=([A-Za-z0-9\-_]+)&.+?</object>#s', $markup, $matches );

			// Find Vimeo embedded with iframe code
			if ( !isset( $matches[1] ) ) {
				preg_match( '#http://player\.vimeo\.com/video/([0-9]+)#', $markup, $matches );
			}

			// If we still haven't found anything, check for Vimeo embedded with JR_embed
			if ( !isset( $matches[1] ) ) {
				preg_match( '#\[vimeo id=([A-Za-z0-9\-_]+)]#', $markup, $matches );
			}

			// If we still haven't found anything, check for Vimeo URL
			if ( !isset( $matches[1] ) ) {
				preg_match( '#(?:http://)?(?:www\.)?vimeo\.com/([A-Za-z0-9\-_]+)#', $markup, $matches );
			}

			// If we still haven't found anything, check for Vimeo shortcode
			if ( !isset( $matches[1] ) ) {
				preg_match( '#\[vimeo clip_id="([A-Za-z0-9\-_]+)"[^>]*]#', $markup, $matches );
			}
			if ( !isset( $matches[1] ) ) {
				preg_match( '#\[vimeo video_id="([A-Za-z0-9\-_]+)"[^>]*]#', $markup, $matches );
			}

			// Now if we've found a Vimeo ID, let's set the thumbnail URL
			if ( isset( $matches[1] ) ) {
				$vimeo_thumbnail = getVimeoInfo( $matches[1], $info = 'thumbnail_large' );
				if ( is_wp_error( $vimeo_thumbnail ) ) {
					return $vimeo_thumbnail;
				} else if ( isset( $vimeo_thumbnail ) ) {
					$new_thumbnail = $vimeo_thumbnail;
				}
			}
		}

		// Blip.tv
		if ( $new_thumbnail == null ) {

			// Blip.tv embed URL
			preg_match( '#http://blip\.tv/play/([A-Za-z0-9]+)#', $markup, $matches );

			// Now if we've found a Blip.tv embed URL, let's set the thumbnail URL
			if ( isset( $matches[1] ) ) {
				$blip_thumbnail = getBliptvInfo( $matches[1] );
				if ( is_wp_error( $blip_thumbnail ) ) {
					return $blip_thumbnail;
				} else if ( isset( $blip_thumbnail ) ) {
					$new_thumbnail = $blip_thumbnail;
				}
			}
		}

		// Justin.tv
		if ( $new_thumbnail == null ) {

			// Justin.tv archive ID
			preg_match( '#archive_id=([0-9]+)#', $markup, $matches );

			// Now if we've found a Justin.tv archive ID, let's set the thumbnail URL
			if ( isset( $matches[1] ) ) {
				$justin_thumbnail = getJustintvInfo( $matches[1] );
				$new_thumbnail = $justin_thumbnail;
			}
		}

		// Dailymotion
		if ( $new_thumbnail == null ) {

			// Dailymotion flash
			preg_match( '#<object[^>]+>.+?http://www\.dailymotion\.com/swf/video/([A-Za-z0-9]+).+?</object>#s', $markup, $matches );

			// Dailymotion url
			if ( !isset( $matches[1] ) ) {
				preg_match( '#(?:https?://)?(?:www\.)?dailymotion\.com/video/([A-Za-z0-9]+)#', $markup, $matches );
			}

			// Dailymotion iframe
			if ( !isset( $matches[1] ) ) {
				preg_match( '#https?://www\.dailymotion\.com/embed/video/([A-Za-z0-9]+)#', $markup, $matches );
			}

			// Now if we've found a Dailymotion video ID, let's set the thumbnail URL
			if ( isset( $matches[1] ) ) {
				$dailymotion_thumbnail = getDailyMotionThumbnail( $matches[1] );
			if ( is_wp_error( $dailymotion_thumbnail ) ) {
					return $dailymotion_thumbnail;
				} else if ( isset( $dailymotion_thumbnail ) ) {
					$new_thumbnail = strtok( $dailymotion_thumbnail, '?' );
				}
			}
		}

		// Metacafe
		if ( $new_thumbnail == null ) {

			// Find ID from Metacafe embed url
			preg_match( '#http://www\.metacafe\.com/fplayer/([A-Za-z0-9\-_]+)/#', $markup, $matches );

			// Now if we've found a Metacafe video ID, let's set the thumbnail URL
			if ( isset( $matches[1] ) ) {
				$metacafe_thumbnail = getMetacafeThumbnail( $matches[1] );
				if ( is_wp_error( $metacafe_thumbnail ) ) {
					return $metacafe_thumbnail;
				} else if ( isset( $metacafe_thumbnail ) ) {
					$new_thumbnail = strtok( $metacafe_thumbnail, '?' );
				}
			}
		}

		// Return the new thumbnail variable and update meta if one is found
		if ( $new_thumbnail != null ) {

			// Save as Attachment if enabled
			if ( get_option( 'video_thumbnails_save_media' ) == 1 ) {

				$response = wp_remote_get( $new_thumbnail, array( 'sslverify' => false ) );

				// Check for error
				if( is_wp_error( $response ) ) {
					return new WP_Error( 'thumbnail_retrieval', __( 'Error retrieving a thumbnail from the URL <a href="' . $new_thumbnail . '">' . $new_thumbnail . '</a> If opening that URL in your web browser shows an image, the problem may be related to your web server and might be something your server administrator can solve. Error details: "' . $response->get_error_message() . '"' ) );
				}

				$image_contents = wp_remote_retrieve_body( $response );

				$upload = wp_upload_bits( basename( $new_thumbnail ), null, $image_contents );

				$new_thumbnail = $upload['url'];

				$filename = $upload['file'];

				$wp_filetype = wp_check_filetype( basename( $filename ), null );
				$attachment = array(
					'post_mime_type'	=> 'video',
					'post_title'		=> get_the_title($post_id),
					'post_content'		=> '',
					'post_status'		=> 'inherit'
				);
				$attach_id = wp_insert_attachment( $attachment, $filename, $post_id );
				// you must first include the image.php file
				// for the function wp_generate_attachment_metadata() to work
				require_once( ABSPATH . 'wp-admin/includes/image.php' );
				$attach_data = wp_generate_attachment_metadata( $attach_id, $filename );
				wp_update_attachment_metadata( $attach_id, $attach_data );
			
			}

			// Add hidden custom field with thumbnail URL
			if ( !update_post_meta( $post_id, '_video_thumbnail', $new_thumbnail ) ) add_post_meta( $post_id, '_video_thumbnail', $new_thumbnail, true );

			// Set attachment as featured image if enabled
			if ( get_option( 'video_thumbnails_set_featured' ) == 1 && get_option( 'video_thumbnails_save_media' ) == 1 && !has_post_thumbnail( $post_id ) ) {
				set_post_thumbnail( $post_id, $attach_id );
			}
		}
		return $new_thumbnail;

	}
};

// Echo thumbnail
function video_thumbnail( $post_id = null ) {
	if ( ( $video_thumbnail = get_video_thumbnail( $post_id ) ) == null ) { echo plugins_url() . '/video-thumbnails/default.jpg'; }
	else { echo $video_thumbnail; }
};

// Create Meta Fields on Edit Page

add_action( 'admin_init', 'video_thumbnail_admin_init' );

function video_thumbnail_admin_init() {
add_meta_box( 'video_thumbnail', 'Video thumbnail', 'video_thumbnail_admin', 'video', 'side', 'low' );
		}
	




















function video_thumbnail_admin() {
	global $post;
	$custom = get_post_custom( $post->ID );
	$video_thumbnail = $custom["_video_thumbnail"][0];

	if ( isset( $video_thumbnail ) && $video_thumbnail != '' ) {
		echo '<p id="video-thumbnails-preview"><img src="' . $video_thumbnail . '" style="max-width:100%;" /></p>';	}

	if ( get_post_status() == 'publish' || get_post_status() == 'private' ) {
		if ( isset( $video_thumbnail ) && $video_thumbnail != '' ) {
			
			
			_e('<p><a href="#" id="video-thumbnails-reset" onclick="video_thumbnails_reset(\'' . $post->ID . '\' );return false;">Update video image</a></p>', 'wpcity');
		} 
		
		
		else {
			_e('<p id="video-thumbnails-preview">Click on the link to create an image.</p>', 'wpcity');
			
		_e('<p><a href="#" id="video-thumbnails-reset" onclick="video_thumbnails_reset(\'' . $post->ID . '\' );return false;">Create Image</a></p>', 'wpcity');	
			
		}
	} else {
		if ( isset( $video_thumbnail ) && $video_thumbnail != '' ) {
			_e('<p><a href="#" id="video-thumbnails-reset" onclick="video_thumbnails_reset(\'' . $post->ID . '\' );return false;">Resetting the video pictures</a></p>', 'wpcity');	
		} else {
			_e('<p>Video image can be created only after the publication of the recording!</p>', 'wpcity');	
		}
	}
}













// AJAX Searching

if ( in_array( basename( $_SERVER['PHP_SELF'] ), apply_filters( 'video_thumbnails_editor_pages', array( 'post-new.php', 'page-new.php', 'post.php', 'page.php' ) ) ) ) {
	add_action( 'admin_head', 'video_thumbnails_ajax' );
}

function video_thumbnails_ajax() {
?>



<!-- Video Thumbnails Researching Ajax -->
<script type="text/javascript">
function video_thumbnails_reset(id) {

	var data = {
		action: 'video_thumbnails',
		post_id: id
	};

	document.getElementById('video-thumbnails-preview').innerHTML=' <?php _e( 'Wait ideal search!', 'wpcity' ); ?>  <img src="<?php echo home_url( 'wp-admin/images/loading.gif' ); ?>"/>';

	// since 2.8 ajaxurl is always defined in the admin header and points to admin-ajax.php
	jQuery.post(ajaxurl, data, function(response){
		document.getElementById('video-thumbnails-preview').innerHTML=response;
	});
};
</script>
<?php
}

add_action( 'wp_ajax_video_thumbnails', 'video_thumbnails_callback' );

function video_thumbnails_callback() {
	global $wpdb; // this is how you get access to the database

	$post_id = $_POST['post_id'];

	delete_post_meta( $post_id, '_video_thumbnail' );

	$video_thumbnail = get_video_thumbnail( $post_id );

	if ( is_wp_error( $video_thumbnail ) ) {
		echo $video_thumbnail->get_error_message();
	} else if ( $video_thumbnail != null ) {
		echo '<img src="' . $video_thumbnail . '" style="max-width:100%;" />';
	} else {
		_e('<p>Can not create the file, you are doing something wrong!Contact the author of threads <a href="http://www.wp-city.ru/"> www.wp-city.ru </ a></p>', 'wpcity');

	}

	die();
}








?>